@@ -181,7 +181,7 @@
   (nsucccurlyeq (!annotate "\\mathrel{\\not\\succcurlyeq}" (succcurlyeq)))
   (nsucceqq (!annotate "\\mathrel{\\not\\succeqq}" (succeqq)))
   (nsuccsim (!annotate "\\mathrel{\\not\\succsim}" (succsim)))
-  
+
   ;; other extra symbols
   (oempty "\\circ")
   (exterior "\\wedge")
@@ -246,7 +246,60 @@
   (rightmap (!group (!append (shortmid) "\\!\\!\\!-")))
   (leftmap (!group (!append "-\\!\\!\\!" (shortmid))))
   (leftrightmap (!group (!append (shortmid) "\\!\\!\\!-\\!\\!\\!"
-                                 (shortmid)))))
+                                 (shortmid))))
+  (LRleftrightarrow (!group (!append (Lleftarrow) "\\!\\!\\!" (Rrightarrow))))
+  (Llongleftarrow (!group (!append (Lleftarrow) "\\!" (equiv))))
+  (Llongrightarrow (!group (!append (equiv) "\\!" (Rrightarrow))))
+  (Llongleftrightarrow (!group (!append (Lleftarrow) "\\!" (equiv)
+                                        "\\!" (Rrightarrow))))
+  (threeleftarrows
+   (mathrel (substack (!append (leftarrow) "\\\\[-0.6ex]"
+                               (leftarrow) "\\\\[-0.6ex]"
+                               (leftarrow)))))
+  (fourleftarrows
+   (mathrel (substack (!append (leftarrow) "\\\\[-0.6ex]"
+                               (leftarrow) "\\\\[-0.6ex]"
+                               (leftarrow) "\\\\[-0.6ex]"
+                               (leftarrow)))))
+  (threerightarrows
+   (mathrel (substack (!append (rightarrow) "\\\\[-0.6ex]"
+                               (rightarrow) "\\\\[-0.6ex]"
+                               (rightarrow)))))
+  (fourrightarrows
+   (mathrel (substack (!append (rightarrow) "\\\\[-0.6ex]"
+                               (rightarrow) "\\\\[-0.6ex]"
+                               (rightarrow) "\\\\[-0.6ex]"
+                               (rightarrow)))))
+  (longleftrightarrows
+   (mathrel (substack (!append (longleftarrow) "\\\\[-0.6ex]"
+                               (longrightarrow)))))
+  (longleftleftarrows
+   (mathrel (substack (!append (longleftarrow) "\\\\[-0.6ex]"
+                               (longleftarrow)))))
+  (longthreeleftarrows
+   (mathrel (substack (!append (longleftarrow) "\\\\[-0.6ex]"
+                               (longleftarrow) "\\\\[-0.6ex]"
+                               (longleftarrow)))))
+  (longfourleftarrows
+   (mathrel (substack (!append (longleftarrow) "\\\\[-0.6ex]"
+                               (longleftarrow) "\\\\[-0.6ex]"
+                               (longleftarrow) "\\\\[-0.6ex]"
+                               (longleftarrow)))))
+  (longrightleftarrows
+   (mathrel (substack (!append (longrightarrow) "\\\\[-0.6ex]"
+                               (longleftarrow)))))
+  (longrightrightarrows
+   (mathrel (substack (!append (longrightarrow) "\\\\[-0.6ex]"
+                               (longrightarrow)))))
+  (longthreerightarrows
+   (mathrel (substack (!append (longrightarrow) "\\\\[-0.6ex]"
+                               (longrightarrow) "\\\\[-0.6ex]"
+                               (longrightarrow)))))
+  (longfourrightarrows
+   (mathrel (substack (!append (longrightarrow) "\\\\[-0.6ex]"
+                               (longrightarrow) "\\\\[-0.6ex]"
+                               (longrightarrow) "\\\\[-0.6ex]"
+                               (longrightarrow))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Extra TeXmacs macros
@@ -266,6 +319,10 @@
              (!group (!recurse (TeXmacs))) " " (!translate "text editor") " ("
              (!translate "see") " "
              (url "http://www.texmacs.org") ")"))
+  (citewebsite
+    (!append (!translate "This document has been written using") " GNU "
+             (!group (!recurse (TeXmacs))) "; " (!translate "see") " "
+             (url "http://www.texmacs.org") "."))
   (tmmade (!recurse (tikzframe (Backsigma))))
   (scheme "{\\sc Scheme}")
   (tmsep  ", ")
@@ -323,10 +380,28 @@
   (tmieeeemail (!append (textit (!translate "Email:")) " " 1))
   (tmnote (thanks (!append (textit (!translate "Note:")) " " 1)))
   (tmmisc (thanks (!append (textit (!translate "Misc:")) " " 1)))
+  (citetexmacs
+    (!append (!translate "This document has been written using") " GNU "
+             (!group (!recurse (TeXmacs))) " " (cite 1) "."))
   (key (!append
          (fcolorbox "black" "gray!25!white"
                     (raisebox "0pt" (!option "5pt") (!option "0pt") (texttt 1)))
          (hspace "0.5pt")))
+  (uhat (underaccent (hat) 1))
+  (uwidehat (underaccent (widehat (hphantom 1)) 1))
+  (utilde (underaccent (tilde) 1))
+  (uwidetilde (underaccent (widetilde (hphantom 1)) 1))
+  (uvec (underaccent (vec) 1))
+  (ubreve (underaccent (breve) 1))
+  (uinvbreve (underaccent (invbreve) 1))
+  (ucheck (underaccent (check) 1))
+  (uring (underaccent (ring) 1))
+  (uacute (underaccent (acute) 1))
+  (ugrave (underaccent (grave) 1))
+  (underdot (underaccent (dot) 1))
+  (uddot (underaccent (ddot) 1))
+  (udddot (underaccent (dddot (hphantom 1)) 1))
+  (uddddot (underaccent (ddddot (hphantom 1)) 1))
 
   ;; With options
   (tmcodeinline ((!option "") (!group (ttfamily) (!group 2))))
@@ -495,6 +570,14 @@
    (!append (begingroup) "\\setlength{\\parskip}{" 1 "}"
             ---
             (endgroup)))
+  ("tmcompact"
+   ((!begin "tmparsep" "0em") ---))
+  ("tmcompressed"
+   ((!begin "tmparsep" "0.25em") ---))
+  ("tmamplified"
+   ((!begin "tmparsep" "0.75em") ---))
+  ("tmjumpin"
+   ((!begin "tmparmod" "1.5em" "0pt" "-1.5em") ---))
   ("tmindent"
    ((!begin "tmparmod" "1.5em" "0pt" "0pt") ---))
   ("tmlisting"
@@ -540,6 +623,7 @@
 (latex-texmacs-description "descriptionaligned")
 (latex-texmacs-description "descriptiondash")
 (latex-texmacs-description "descriptionlong")
+(latex-texmacs-description "descriptionparagraphs")
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Extra preamble definitions which are needed to export certain macros
@@ -611,6 +695,11 @@
   (mho
    (!append
     "\\renewcommand{\\mho}{\\mbox{\\rotatebox[origin=c]{180}{$\\omega$}}}"))
+  (invbreve
+   (!append
+    "\\usepackage[T3,T1]{fontenc}\n"
+    "\\DeclareSymbolFont{tipa}{T3}{cmr}{m}{n}\n"
+    "\\DeclareMathAccent{\\invbreve}{\\mathalpha}{tipa}{16}\n"))
   (custombinding
    (!append
     "\\newcounter{tmcounter}\n"
